@@ -158,7 +158,8 @@ class FlaviusHeader(FlaviusBase):
     def __init__(self):
         super(FlaviusHeader, self).__init__(search_url=conf.FLAVIUS_API_HEADER_FETCH,
                                             create_url=conf.FLAVIUS_API_HEADER_CREATE,
-                                            update_url='', delete_url='')
+                                            update_url=conf.FLAVIUS_API_HEADER_MODIFY,
+                                            delete_url='')
 
     def search(self, query=None):
         self.search_url += parse.urlencode(query=query, doseq=True)
